Index: src/ast/scopes.h |
diff --git a/src/ast/scopes.h b/src/ast/scopes.h |
index 0c10633e02fdc387cd7e238dafe9b98839b82744..1bec87f6636aeb1857d0217350b14c77adf907b9 100644 |
--- a/src/ast/scopes.h |
+++ b/src/ast/scopes.h |
@@ -371,6 +371,9 @@ class Scope: public ZoneObject { |
// 'this' is bound, and what determines the function kind. |
DeclarationScope* GetReceiverScope(); |
+ // Find the module scope, assuming there is one. |
+ ModuleScope* GetModuleScope(); |
+ |
// Analyze() must have been called once to create the ScopeInfo. |
Handle<ScopeInfo> scope_info() { |
DCHECK(!scope_info_.is_null()); |
@@ -677,9 +680,9 @@ class DeclarationScope : public Scope { |
} |
// Parameters. The left-most parameter has index 0. |
// Only valid for function scopes. |
Variable* parameter(int index) const { |
- DCHECK(is_function_scope()); |
+ DCHECK(is_function_scope() || is_module_scope()); |
return params_[index]; |
} |
@@ -677,9 +680,9 @@ class DeclarationScope : public Scope { |
} |
// Parameters. The left-most parameter has index 0. |
- // Only valid for function scopes. |
+ // Only valid for function and module scopes. |
Variable* parameter(int index) const { |